# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/), and this project
adheres to [Semantic Versioning](https://semver.org/).

For the purpose of determining breaking changes:

- Only direct imports from top-level module `unpaginate` are considered public API
- A change that only impacts type hints validation is not considered a breaking change
- Removing support for a version of Python that is not [officially
  supported][python-versions] anymore is not considered a breaking change

[python-versions]: https://devguide.python.org/versions/#supported-versions

## [0.1.0] - 2024-04-28

[0.1.0]: https://github.com/rogdham/unpaginate/releases/tag/v0.1.0

### :rocket: Added

- Initial public release :tada:
